@@ -3,7 +3,7 @@ package Specio::Library::Structured::Tuple;
 use strict;
 use warnings;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use Carp qw( confess );
 use List::Util ();
@@ -17,7 +17,7 @@ sub parent {$arrayref}
 
 ## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _inline {
-    $arrayref->_inline_check( $_[1] );
+    $arrayref->inline_check( $_[1] );
 }
 
 sub _parameterization_args_builder {
@@ -182,7 +182,7 @@ Specio::Library::Structured::Tuple - Guts of Tuple structured type
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 DESCRIPTION
 
